pub struct BufferedDecoder { /* private fields */ }Expand description
A buffered GIF decoder that loads and composites all frames.
This decoder properly handles GIF disposal methods and transparency, producing fully composited RGBA frames suitable for analysis.
Example
ⓘ
use figif_core::decoders::BufferedDecoder;
use figif_core::traits::GifDecoder;
let decoder = BufferedDecoder::new();
let frames: Vec<_> = decoder.decode_file("animation.gif")?.collect::<Result<Vec<_>, _>>()?;Implementations
Sourceimpl BufferedDecoder
impl BufferedDecoder
Sourcepub fn with_memory_limit(self, limit: usize) -> Self
pub fn with_memory_limit(self, limit: usize) -> Self
Set a memory limit for decoding.
If the GIF would require more memory than this limit, decoding will fail with an error.