PHasher

Struct PHasher 

pub struct PHasher { /* private fields */ }
Perceptual hash (pHash) using Discrete Cosine Transform.

pHash is more robust to image transformations than simpler hashes but is slower to compute. It works by analyzing the frequency components of the image.

Algorithm

  1. Resize image to 32x32
  2. Convert to grayscale
  3. Apply DCT (Discrete Cosine Transform)
  4. Keep only low-frequency components (top-left 8x8)
  5. Compute median and create hash based on above/below median

Example

use figif_core::hashers::PHasher;
use figif_core::traits::FrameHasher;

let hasher = PHasher::new();
let hash = hasher.hash_frame(&image);

Implementations

Source

impl PHasher

pub fn new() -> Self

Create a new pHash hasher with default 8x8 hash size.

pub fn with_size(width: u32, height: u32) -> Self

Create a pHash hasher with custom hash dimensions.

The actual DCT is computed on a larger image (4x the hash size), then only the low-frequency components are kept.

pub fn hash_width(&self) -> u32

Get the hash width.

pub fn hash_height(&self) -> u32

Get the hash height.

pub fn hash_bits(&self) -> u32

Get the total hash bits.