Module segment

Module segment 

Segment operations and manipulation.

Structs

SegmentStats
Compute statistics for a set of segments.

Functions

apply_operations
This is the enhanced version that handles frame-level operations like individual frame removal and segment splitting.
apply_segment_operations
Apply segment operations to analyzed frames, producing encodable frames.
dry_run_all_operations
Calculate the impact of all operations without cloning images.
dry_run_segment_operations
Calculate the impact of segment operations without cloning images.
find_longest_segment
Find the longest segment.
find_pause_segments
Find segments that are likely “pause” segments (static with long duration).
split_segments_at_points
Partition existing segments into new ones based on FrameOp::SplitAfter markers.
suggest_compression_ops
Suggest operations to reduce GIF duration by targeting static segments.