HashBasedSimilarity

Struct HashBasedSimilarity 

pub struct HashBasedSimilarity<H> { /* private fields */ }
A similarity metric based on a hash distance threshold.

This adapter allows using a FrameHasher as a SimilarityMetric.

Implementations

Source

impl<H> HashBasedSimilarity<H>

pub fn new(hasher: H, max_distance: u32) -> Self

Create a new hash-based similarity metric.

max_distance is the maximum hash distance that maps to similarity > 0.