BufferedGifDecoder

Trait BufferedGifDecoder 

pub trait BufferedGifDecoder: GifDecoder {
    // Provided methods
    fn decode_all(&self, data: &[u8]) -> Result<Vec<DecodedFrame>> { ... }
    fn decode_all_from_file(
        &self,
        path: impl AsRef<Path>,
    ) -> Result<Vec<DecodedFrame>> { ... }
}
A decoder that collects all frames into a vector.

This is useful when you need random access to frames or when the streaming approach is not suitable.

Provided Methods

fn decode_all(&self, data: &[u8]) -> Result<Vec<DecodedFrame>>

Decode all frames into a vector.

fn decode_all_from_file( &self, path: impl AsRef<Path>, ) -> Result<Vec<DecodedFrame>>

Decode all frames from a file into a vector.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors