pub struct PHasher { /* private fields */ }Expand description
Perceptual hash (pHash) using Discrete Cosine Transform.
pHash is more robust to image transformations than simpler hashes but is slower to compute. It works by analyzing the frequency components of the image.
Algorithm
- Resize image to 32x32
- Convert to grayscale
- Apply DCT (Discrete Cosine Transform)
- Keep only low-frequency components (top-left 8x8)
- Compute median and create hash based on above/below median
Example
ⓘ
use figif_core::hashers::PHasher;
use figif_core::traits::FrameHasher;
let hasher = PHasher::new();
let hash = hasher.hash_frame(&image);Implementations
Sourceimpl PHasher
impl PHasher
Sourcepub fn with_size(width: u32, height: u32) -> Self
pub fn with_size(width: u32, height: u32) -> Self
Create a pHash hasher with custom hash dimensions.
The actual DCT is computed on a larger image (4x the hash size), then only the low-frequency components are kept.
Sourcepub fn hash_width(&self) -> u32
pub fn hash_width(&self) -> u32
Get the hash width.
Sourcepub fn hash_height(&self) -> u32
pub fn hash_height(&self) -> u32
Get the hash height.