Segment operations and manipulation.
Structs
- Segment
Stats - Compute statistics for a set of segments.
Functions
- apply_
operations - This is the enhanced version that handles frame-level operations like individual frame removal and segment splitting.
- apply_
segment_ operations - Apply segment operations to analyzed frames, producing encodable frames.
- dry_
run_ all_ operations - Calculate the impact of all operations without cloning images.
- dry_
run_ segment_ operations - Calculate the impact of segment operations without cloning images.
- find_
longest_ segment - Find the longest segment.
- find_
pause_ segments - Find segments that are likely “pause” segments (static with long duration).
- split_
segments_ at_ points - Partition existing segments into new ones based on
FrameOp::SplitAftermarkers. - suggest_
compression_ ops - Suggest operations to reduce GIF duration by targeting static segments.